@@ -131,7 +131,7 @@ namespace snmalloc
      * high memory pressure conditions, though on Linux this seems to impose
      * too much of a performance penalty.
      */
-    void notify_not_using(void* p, size_t size) noexcept
+    static void notify_not_using(void* p, size_t size) noexcept
     {
       SNMALLOC_ASSERT(is_aligned_block<OS::page_size>(p, size));
 #ifdef USE_POSIX_COMMIT_CHECKS
@@ -150,7 +150,7 @@ namespace snmalloc
      * function.
      */
     template<ZeroMem zero_mem>
-    void notify_using(void* p, size_t size) noexcept
+    static void notify_using(void* p, size_t size) noexcept
     {
       SNMALLOC_ASSERT(
         is_aligned_block<OS::page_size>(p, size) || (zero_mem == NoZero));
@@ -163,7 +163,7 @@ namespace snmalloc
 #endif
 
       if constexpr (zero_mem == YesZero)
-        static_cast<OS*>(this)->template zero<true>(p, size);
+        zero<true>(p, size);
     }
 
     /**
@@ -178,7 +178,7 @@ namespace snmalloc
      * calling bzero at some point.
      */
     template<bool page_aligned = false>
-    void zero(void* p, size_t size) noexcept
+    static void zero(void* p, size_t size) noexcept
     {
       if (page_aligned || is_aligned_block<OS::page_size>(p, size))
       {
@@ -207,7 +207,7 @@ namespace snmalloc
      * POSIX does not define a portable interface for specifying alignment
      * greater than a page.
      */
-    std::pair<void*, size_t> reserve_at_least(size_t size) noexcept
+    static std::pair<void*, size_t> reserve_at_least(size_t size) noexcept
     {
       SNMALLOC_ASSERT(size == bits::next_pow2(size));
 
